#!/usr/bin/gnuplot

h = 3600.
km = 1.e3

P = 5.385*h

scale = 1.0

omega = 2*pi/P
Ueff(x,y,U) = U - 1./2.*omega**2*(x**2+y**2)

########################################################################

set term qt

#set xl "{/Helvetica-Oblique x} [km]"
set yl "{/Helvetica-Oblique y} [km]"
set zl "U [J kg^-1]"

tmp=250
set xr [-tmp:tmp]
set yr [-tmp:tmp]
z1=-10000
z2=0
set zr [z1:z2]
set ztics 1000
set xyplane 0.0
set view equal xy
set view 0,0
set nokey
set contour base; set nosurface; pa=0
#set contour surface; set surface; pa=-1  # dbg

L1 = -2973.0; set cntrparam levels discrete L1  # right
L2 = -2891.8; set cntrparam levels discrete L2  # left
L3 = -2154.5; set cntrparam levels discrete L3  # up
L4 = -2152.0; set cntrparam levels discrete L4  # down

set cntrparam levels increment -500,-250,-10000

set table "gravity3a.dat"
sp "gravity3.out" u 1:2:(Ueff($1*km,$2*km,$4)) w l lc 'gray'; pa pa
unset table

set cntrparam levels discrete L1, L2, L3, L4

set table "gravity3b.dat"
rep
unset table

L1x = +163.0; L1y =    0.0
L2x = -157.0; L2y =    0.0
L3x =   +7.8; L3y = +105.0
L4x =   +2.2; L4y = -105.0

set label "  L_1"    at L1x-1, L1y font "Helvetica,14" front
set label "L_2"      at L2x-5, L2y font "Helvetica,10" front right
set label "   L_3" at L3x  , L3y font "Helvetica,14" front
set label "   L_4" at L4x  , L4y font "Helvetica,14" front

p \
  "gravity3a.dat" u 1:2 w l lc 'gray',\
  "gravity3b.dat" u 1:2 w l lc 'blue',\
  "<./face.awk tri_file_octdec_3.1.node tri_file_octdec_3.1.face" u ($1*scale):($2*scale) w l lc '#ff6600' lw 0.5,\
  "<echo 1 1" u (L1x):(L1y) w p pt 1 lc 'black',\
  "<echo 1 1" u (L2x):(L2y) w p pt 1 lc 'black',\
  "<echo 1 1" u (L3x):(L3y) w p pt 1 lc 'black',\
  "<echo 1 1" u (L4x):(L4y) w p pt 1 lc 'black'

pa -1

set term post eps color solid enh "Helvetica,18"
set size 0.75,1.0
set out "gravity3__5.385.eps"
rep

q


