! multipole.f90
! Compute multipole expansion coefficients.
! Miroslav Broz (miroslav.broz@email.cz), Nov 14th 2019

module multipole_module

implicit none

contains

subroutine multipole(elems, nodes, capm, capr, rho, Clm, Slm)

use factorial_module
use volume_module
use legendre_module

integer, dimension(:,:), pointer :: elems
double precision, dimension(:,:), pointer :: nodes
double precision :: capm, capr, rho
double precision, dimension(0:,0:) :: Clm, Slm

integer :: i,l,m
double precision :: dV, costheta, phi, absr, tmp
double precision, dimension(3) :: a, b, c, d, r

Clm = 0.d0
Slm = 0.d0

do i = 1, size(elems,1)
  a = nodes(elems(i,1),:)
  b = nodes(elems(i,2),:)
  c = nodes(elems(i,3),:)
  d = nodes(elems(i,4),:)

  dV = v1(a,b,c,d)
  r = (a+b+c+d)/4.d0
  absr = sqrt(dot_product(r,r))
  costheta = r(3)/absr
  phi = atan2(r(2),r(1))

  do l = 0, size(Clm,1)-1
    do m = 0, l
      if (m.eq.0) then
        tmp = 1.d0/(capm*capr**l) * rho*(absr**l) * Pl(l,costheta) * dV
        Clm(l,m) = Clm(l,m) + tmp
      else
!        tmp = 1.d0/(2.d0*capm*capr**l) * factorial(l-m)/factorial(l+m) * rho*(absr**l) * Plm(l,m,costheta) * dV  ! Sidlichovsky
        tmp = 2.d0/(capm*capr**l) * factorial(l-m)/factorial(l+m) * rho*(absr**l) * Plm(l,m,costheta) * dV  ! multiplied by 4
        Clm(l,m) = Clm(l,m) + tmp*cos(m*phi)
        Slm(l,m) = Slm(l,m) + tmp*sin(m*phi)
      endif
    enddo
  enddo

enddo

return

end subroutine multipole

end module multipole_module


